@@ -46,7 +46,7 @@ def _FuncFromModule(module: types.ModuleType) -> typing.List[typing.Callable]:
             continue
         sig = inspect.signature(x)
         print(f">>{name}: {sig}")
-        for arg in sig.parameters:
+        for arg in sig.parameters.values():
             convert = ArgumentConversion(arg)
             if not convert.valid:
                 break
@@ -60,6 +60,9 @@ def _FuncFromModule(module: types.ModuleType) -> typing.List[typing.Callable]:
 class ArgumentConversion:
     def __init__(self, p: inspect.Parameter):
         self.name = p.name
+        self._convert = None
+        self.need_event = False
+        self.unknownArg = None
         TYPE_TO_TRANSLATION = {
             ce_sdk.BaseEvent: (lambda x: x, True),
             flask.Request: (lambda x: x, False),
@@ -76,7 +79,7 @@ class ArgumentConversion:
         if p.annotation in TYPE_TO_TRANSLATION:
             self._convert, self.need_event = TYPE_TO_TRANSLATION[p.annotation]
         if p.name in NAME_TO_TRANSLATION:
-            self._convert, self.need_event = NAME_TO_TRANSLATION[p.annotation]
+            self._convert, self.need_event = NAME_TO_TRANSLATION[p.name]
 
         if p.default == inspect.Parameter.empty:
             if p.kind not in (
